# Select an existing model

In this workflow, **currently you only have access to the {bdg-dark-line}`Prediction` & {bdg-dark-line}`Thresholding` modules**.

Any model that was previously created or downloaded by the plugin will be available for selecting in the dropdown.

## STEPS

1. Select "Select an existing model” option *AND* select a model available from the dropdown
2. Click `Apply`
3. Follow {ref}`"Prediction & Thresholding" step-by-step guide<Use Prediction & Thresholding Modules>`

:::{figure} images/Prediction.png
:::

:::{tip} 
To start, we recommend testing our pre-trained models to see how they perform on your data. {ref}`Here is how<3. Download pre-trained models (OPTIONAL)>`
:::

